==> 0.0.1.tar.gz: lib/uis/bns/carousel_cross_word_style.dart <==
import 'package:flutter/material.dart';

class CarouselCrossWordStyle extends StatefulWidget {
  final List<String> images;
  final double viewportFraction;
  final PageController pageController;
  final void Function(int) bnPressed;
  final void Function(int) bnSmallPressed;
  final double bnWrapperHeight;
  final double bnSmallWrapperHeight;
  final Widget Function(BuildContext, int) bnChild;
  final Widget Function(BuildContext, int) bnSmallChild;
  final void Function(int) currentIndex;

  const CarouselCrossWordStyle({
    Key? key,
    required this.images,
    required this.viewportFraction,
    required this.pageController,
    required this.bnPressed,
    required this.bnChild,
    required this.bnSmallPressed,
    required this.bnSmallChild,
    required this.currentIndex,
    this.bnWrapperHeight = 300.0,
    this.bnSmallWrapperHeight = 100.0,
  }) : super(key: key);

  @override
  _CarouselCrossWordStyleState createState() => _CarouselCrossWordStyleState();
}

class _CarouselCrossWordStyleState extends State<CarouselCrossWordStyle> {

  int _pageIndex = 0;
  int _viewCount = 0;

  @override
  void initState() {
    _viewCount = (widget.pageController.viewportFraction*10).toInt();
    super.initState();
  }

  @override
  Widget build(BuildContext context) => SizedBox(
    width: MediaQuery.of(context).size.width,
    child: Column(
      children: [
        SizedBox(
          width: MediaQuery.of(context).size.width,
          height: widget.bnWrapperHeight,
          child: PageView.builder(
            onPageChanged: _onPageChanged,
            itemCount: widget.images.length,
            itemBuilder: (BuildContext context, int i) => GestureDetector(
              onTap: () => widget.bnPressed(i),
              child: widget.bnChild(context, i),
            ),
          )
        ),
        SizedBox(
          width: MediaQuery.of(context).size.width,
          height: widget.bnSmallWrapperHeight,
          child: PageView.builder(
            physics: const NeverScrollableScrollPhysics(),
            controller: widget.pageController,
            padEnds: false,
            itemCount: widget.images.length,
            itemBuilder: (BuildContext context, int i) => GestureDetector(
              onTap: () => widget.bnSmallPressed(i),
              child: widget.bnSmallChild(context, i),
            ),
          )
        ),
      ],
    ),
  );

  void _onPageChanged(int i){
    if(!mounted) return;
    if(!widget.pageController.hasClients) return;
    int _pIndex = i~/_viewCount;
    if(_pageIndex != _pIndex){
      if(_pageIndex <= _pIndex){widget.pageController.jumpToPage(i);}
      else {widget.pageController.jumpToPage(_pIndex*_viewCount);}
      _pageIndex = _pIndex;
    }
    setState(() => widget.currentIndex(i));
  }
}

==> 0.0.2.tar.gz: lib/uis/bns/carousel_cross_word_style.dart <==
import 'package:flutter/material.dart';

class JamesCarouselCrossWordStyle extends StatefulWidget {
  final List<String> images;
  final double viewportFraction;
  final PageController pageController;
  final void Function(int) bnPressed;
  final void Function(int) bnSmallPressed;
  final double bnWrapperHeight;
  final double bnSmallWrapperHeight;
  final Widget Function(BuildContext, int) bnChild;
  final Widget Function(BuildContext, int) bnSmallChild;
  final void Function(int) currentIndex;

  const JamesCarouselCrossWordStyle({
    Key? key,
    required this.images,
    required this.viewportFraction,
    required this.pageController,
    required this.bnPressed,
    required this.bnChild,
    required this.bnSmallPressed,
    required this.bnSmallChild,
    required this.currentIndex,
    this.bnWrapperHeight = 300.0,
    this.bnSmallWrapperHeight = 100.0,
  }) : super(key: key);

  @override
  _JamesCarouselCrossWordStyleState createState() => _JamesCarouselCrossWordStyleState();
}

class _JamesCarouselCrossWordStyleState extends State<JamesCarouselCrossWordStyle> {

  int _pageIndex = 0;
  int _viewCount = 0;

  @override
  void initState() {
    _viewCount = (widget.pageController.viewportFraction*10).toInt();
    super.initState();
  }

  @override
  Widget build(BuildContext context) => SizedBox(
    width: MediaQuery.of(context).size.width,
    child: Column(
      children: [
        SizedBox(
          width: MediaQuery.of(context).size.width,
          height: widget.bnWrapperHeight,
          child: PageView.builder(
            onPageChanged: _onPageChanged,
            itemCount: widget.images.length,
            itemBuilder: (BuildContext context, int i) => GestureDetector(
              onTap: () => widget.bnPressed(i),
              child: widget.bnChild(context, i),
            ),
          )
        ),
        SizedBox(
          width: MediaQuery.of(context).size.width,
          height: widget.bnSmallWrapperHeight,
          child: PageView.builder(
            physics: const NeverScrollableScrollPhysics(),
            controller: widget.pageController,
            padEnds: false,
            itemCount: widget.images.length,
            itemBuilder: (BuildContext context, int i) => GestureDetector(
              onTap: () => widget.bnSmallPressed(i),
              child: widget.bnSmallChild(context, i),
            ),
          )
        ),
      ],
    ),
  );

  void _onPageChanged(int i){
    if(!mounted) return;
    if(!widget.pageController.hasClients) return;
    int _pIndex = i~/_viewCount;
    if(_pageIndex != _pIndex){
      if(_pageIndex <= _pIndex){widget.pageController.jumpToPage(i);}
      else {widget.pageController.jumpToPage(_pIndex*_viewCount);}
      _pageIndex = _pIndex;
    }
    setState(() => widget.currentIndex(i));
  }
}
